import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { useGestureResponder } from "react-gesture-responder";
import { useSpring } from "react-spring";
import PropTypes from "prop-types";
import { safeBind } from "./Hooks/compose-bind";
/**
 * A scroll view with some helpers, including:
 *  - smooth scrolling
 *  - gesture claiming
 * @param param0
 * @param componentRef  改成 ref
 */
//export const ScrollView= React.forwardRef(ScrollViewForward);   // 报警！嵌套RefForwardingComponent 的forwardRef;
export const ScrollView = React.forwardRef(({ overflowY, children, overflowX, innerRef, scrollAnimationConfig = { tension: 190, friction: 15, mass: 0.2 }, ...other }, ref) => {
    const scrRef = React.useRef(null);
    /**
     * A spring for animating scroll positions
     */
    const [, setScroll] = useSpring(() => {
        return {
            config: scrollAnimationConfig,
            from: { x: 0, y: 0 },
            to: { x: 0, y: 0 },
            onFrame: (animated) => {
                if (overflowX && scrRef.current) {
                    scrRef.current.scrollLeft = animated.x;
                }
                if (overflowY && scrRef.current) {
                    scrRef.current.scrollTop = animated.y;
                }
            }
        };
    });
    /**
     * Expose an imperate scrollTo method
     */
    React.useImperativeHandle(ref, () => ({
        scrollTo: (x, y) => {
            if (scrRef.current) {
                const from = {
                    x: scrRef.current.scrollLeft,
                    y: scrRef.current.scrollTop
                };
                setScroll({
                    from,
                    to: { x, y },
                    reset: true
                });
            }
        }
    }), [setScroll]);
    /**
     * Use a pan responder to determine if our scrollview should
     * claim the responder (and cancel other gestures out). Only
     * enabled on touch devices.
     */
    const { bind } = useGestureResponder({
        onStartShouldSet: () => false,
        onTerminationRequest: () => false,
        onMoveShouldSet: ({ initial, initialDirection, xy }) => {
            if (initialDirection[0] !== 0 && overflowX) {
                return true;
            }
            if (initialDirection[1] !== 0 && overflowY) {
                return true;
            }
            return false;
        }
    }, {
        enableMouse: false
    });
    // 不可把innerRef?  与 ref?  都绑定到内部第二个div，scrRef上。
    return (_jsx("div", { className: "ScrollView", ...other, ...bind, children: _jsx("div", { className: "ScrollView__scroll-containerr", css: {
                transform: "translateZ(0)",
                overflowX: overflowX ? "scroll" : undefined,
                overflowY: overflowY ? "scroll" : undefined,
                WebkitOverflowScrolling: "touch"
            }, ...safeBind({ ref: innerRef }, { ref: scrRef }, other), children: children }) }));
});
ScrollView.propTypes = {
    overflowY: PropTypes.bool,
    children: PropTypes.node,
    overflowX: PropTypes.bool,
    scrollAnimationConfig: PropTypes.shape({
        tension: PropTypes.number,
        mass: PropTypes.number,
        friction: PropTypes.number
    })
};
//# sourceMappingURL=ScrollView.js.map