import { jsx as _jsx } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from "@emotion/react";
import * as React from "react";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
export const getVariantStyles = (theme, variant) => {
    switch (variant) {
        case "uppercase":
            return css({
                textTransform: "uppercase",
                fontSize: theme.fontSizes[0],
                fontWeight: 600,
                color: theme.colors.text.muted,
                letterSpacing: "-0.02em"
            });
        case "body":
            return css({
                fontSize: theme.fontSizes[1]
            });
        case "paragraph":
            return css({
                fontSize: theme.fontSizes[1],
                marginBottom: theme.spaces.md
            });
        case "subtitle":
            return css({
                fontSize: theme.fontSizes[0],
                fontWeight: 400,
                color: theme.colors.text.muted,
                lineHeight: theme.lineHeights.body
            });
        case "lead":
            return css({
                fontWeight: 400,
                fontSize: theme.fontSizes[2]
            });
        case "h6":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                lineHeight: 1.5,
                fontSize: theme.fontSizes[1],
                marginBottom: theme.spaces.sm
            });
        case "h5":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[2],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm
            });
        case "h4":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[3],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "h3":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[4],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm
            });
        case "h2":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[5],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "h1":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.heading,
                fontSize: theme.fontSizes[6],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                letterSpacing: "-0.2px"
            });
        case "display3":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[5],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[6]
                }
            });
        case "display2":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[6],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[7]
                }
            });
        case "display1":
            return css({
                color: theme.colors.text.heading,
                fontWeight: theme.fontWeights.display,
                fontSize: theme.fontSizes[7],
                lineHeight: theme.lineHeights.heading,
                marginBottom: theme.spaces.sm,
                [theme.mediaQueries.lg]: {
                    fontSize: theme.fontSizes[8]
                }
            });
    }
};
const element = {
    display1: "h1",
    display2: "h1",
    display3: "h1",
    h1: "h1",
    h2: "h2",
    h3: "h3",
    h4: "h4",
    h5: "h5",
    h6: "h6",
    uppercase: "div",
    subtitle: "div",
    body: "span",
    paragraph: "p",
    hidden: "span",
    lead: "p"
};
const basicStyles = (theme) => ({
    base: css({
        boxSizing: "border-box",
        margin: 0,
        fontWeight: theme.fontWeights.body,
        lineHeight: theme.lineHeights.body,
        fontFamily: theme.fonts.base,
        fontSize: theme.fontSizes[1],
        color: theme.colors.text.default,
        WebkitFontSmoothing: "antialiased",
        WebkitTextSizeAdjust: "none"
    }),
    noGutter: css({
        marginBottom: 0
    }),
    noWrap: css({
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap"
    }),
    muted: css({
        color: theme.colors.text.muted
    })
});
export const Text = ({ variant = "body", wrap = true, gutter = true, muted, component, ...other }) => {
    const Component = component || element[variant];
    const theme = useTheme();
    const variantStyles = React.useMemo(() => getVariantStyles(theme, variant), [
        theme,
        variant
    ]);
    const styles = React.useMemo(() => basicStyles(theme), [theme]);
    return (_jsx(Component, { css: [
            styles.base,
            !wrap && styles.noWrap,
            muted && styles.muted,
            variantStyles,
            !gutter && styles.noGutter
        ], ...other }));
};
/**针对多个连续<Text>文本之间毫无一点点的间隙定制一个简化组件。
 * 特殊版<Text>； 水平方向的固定 margin: '0 0.2rem'
 * */
export const Itext = ({ variant = "body", wrap = true, gutter = true, muted, component, ...other }) => {
    const Component = component || element[variant];
    const theme = useTheme();
    const variantStyles = React.useMemo(() => getVariantStyles(theme, variant), [
        theme,
        variant
    ]);
    const styles = React.useMemo(() => basicStyles(theme), [theme]);
    return (_jsx(Component, { css: [
            styles.base,
            !wrap && styles.noWrap,
            muted && styles.muted,
            variantStyles,
            !gutter && styles.noGutter,
            {
                margin: '0 0.2rem',
            }
        ], ...other }));
};
Text.propTypes = {
    variant: PropTypes.oneOf([
        "uppercase",
        "hidden",
        "body",
        "paragraph",
        "subtitle",
        "lead",
        "h6",
        "h5",
        "h4",
        "h3",
        "h2",
        "h1",
        "display3",
        "display2",
        "display1"
    ]),
    wrap: PropTypes.bool,
    muted: PropTypes.bool,
    gutter: PropTypes.bool,
    // component: PropTypes.element
};
/**
 * 专门给label搞个Text,融合版本,可指定 for="input_id"
 * htmlFor是个关键参数，用途较大。
 * ...other包含文字string, 本来的纯粹文字或Text描述label 或 children。
 * LabelText代替 <Label>嵌套<Text>的组合方式,减少少标签div嵌套层数可简化，功能替代，优化目的=提高性能。
 */
export const LabelText = ({ variant = "subtitle", wrap = true, gutter = true, muted, htmlFor, ...other }) => {
    const theme = useTheme();
    const variantStyles = React.useMemo(() => getVariantStyles(theme, variant), [
        theme,
        variant
    ]);
    const styles = React.useMemo(() => basicStyles(theme), [theme]);
    return (_jsx("label", { htmlFor: htmlFor, css: [
            styles.base,
            !wrap && styles.noWrap,
            muted && styles.muted,
            variantStyles,
            !gutter && styles.noGutter
        ], ...other }));
};
//# sourceMappingURL=Text.js.map